Enum EntityNotSpawnedError
pub enum EntityNotSpawnedError {
Invalid(InvalidEntityError),
ValidButNotSpawned(EntityValidButNotSpawnedError),
}Expand description
An error that occurs when a specified Entity is expected to be valid and spawned but is not.
Represents an error of either InvalidEntityError (when the entity is invalid) or EntityValidButNotSpawnedError (when the EntityGeneration is correct but the EntityIndex is not spawned).
Variants
Invalid(InvalidEntityError)
The entity was invalid.
ValidButNotSpawned(EntityValidButNotSpawnedError)
The entity was valid but was not spawned.
Implementations