Enum SpawnError
pub enum SpawnError {
Invalid(InvalidEntityError),
AlreadySpawned,
}Expand description
An error that occurs when a specified Entity can not be spawned.
Variants
Invalid(InvalidEntityError)
The Entity to spawn was invalid.
It probably had the wrong generation or was created erroneously.
AlreadySpawned
The Entity to spawn was already spawned.