ComponentCloneCtx

Struct ComponentCloneCtx 

pub struct ComponentCloneCtx<'a, 'b> { /* private fields */ }
Context for component clone handlers.

Provides fast access to useful resources like AppTypeRegistry and allows component clone handler to get information about component being cloned.

Implementations



impl<'a, 'b> ComponentCloneCtx<'a, 'b>

pub fn target_component_written(&self) -> bool

Returns true if write_target_component was called before.

pub fn moving(&self) -> bool

Returns true if used in moving context

pub fn source(&self) -> Entity

Returns the current source entity.

pub fn target(&self) -> Entity

Returns the current target entity.

pub fn component_id(&self) -> ComponentId

Returns the ComponentId of the component being cloned.

pub fn component_info(&self) -> &ComponentInfo

Returns the ComponentInfo of the component being cloned.

pub fn linked_cloning(&self) -> bool

Returns true if the EntityCloner is configured to recursively clone entities. When this is enabled, entities stored in a cloned entity’s RelationshipTarget component with RelationshipTarget::LINKED_SPAWN will also be cloned.

pub fn entity_mapper(&mut self) -> &mut dyn EntityMapper

Returns this context’s EntityMapper.

pub fn write_target_component<C>(&mut self, component: C)
where C: Component,

Writes component data to target entity.

Panics

This will panic if:

  • Component has already been written once.
  • Component being written is not registered in the world.
  • ComponentId of component being written does not match expected ComponentId.

pub unsafe fn write_target_component_ptr(&mut self, ptr: Ptr<'_>)

Writes component data to target entity by providing a pointer to source component data.

Safety

Caller must ensure that the passed in ptr references data that corresponds to the type of the source / target ComponentId. ptr must also contain data that the written component can “own” (for example, this should not directly copy non-Copy data).

Panics

This will panic if component has already been written once.

pub fn write_target_component_reflect(&mut self, component: Box<dyn Reflect>)

Writes component data to target entity.

Panics

This will panic if:

pub fn type_registry(&self) -> Option<&AppTypeRegistry>

Returns AppTypeRegistry if it exists in the world.

NOTE: Prefer this method instead of manually reading the resource from the world.

pub fn queue_entity_clone(&mut self, entity: Entity)

Queues the entity to be cloned by the current EntityCloner

pub fn queue_deferred( &mut self, deferred: impl FnOnce(&mut World, &mut dyn EntityMapper) + 'static, )

Queues a deferred clone operation, which will run with exclusive World access immediately after calling the clone handler for each component on an entity. This exists, despite its similarity to Commands, to provide access to the entity mapper in the current context.