Struct EntityIndex
pub struct EntityIndex(/* private fields */);Expand description
This represents the index of an Entity within the Entities array.
This is a lighter weight version of Entity.
This is a unique identifier for an entity in the world.
This differs from Entity in that Entity is unique for all entities total (unless the Entity::generation wraps),
but this is only unique for entities that are active.
This can be used over Entity to improve performance in some cases,
but improper use can cause this to identify a different entity than intended.
Use with caution.
Implementations
impl EntityIndex
impl EntityIndex
pub const fn new(index: NonMaxU32) -> EntityIndex
pub const fn new(index: NonMaxU32) -> EntityIndex
Constructs a new EntityIndex from its index.
pub const fn from_raw_u32(index: u32) -> Option<EntityIndex>
pub const fn from_raw_u32(index: u32) -> Option<EntityIndex>
Equivalent to new except that it takes a u32 instead of a NonMaxU32.
Returns None if the index is u32::MAX.