Struct UniqueEntityIter
pub struct UniqueEntityIter<I>{ /* private fields */ }Expand description
An iterator that yields unique entities.
This wrapper can provide an EntitySetIterator implementation when an instance of I is known to uphold uniqueness.
Implementations
impl<I> UniqueEntityIter<I>where
I: EntitySetIterator,
impl<I> UniqueEntityIter<I>where
I: EntitySetIterator,
pub const fn from_entity_set_iter(iter: I) -> UniqueEntityIter<I> ⓘ
pub const fn from_entity_set_iter(iter: I) -> UniqueEntityIter<I> ⓘ
Constructs a UniqueEntityIter from an EntitySetIterator.
impl<I> UniqueEntityIter<I>
impl<I> UniqueEntityIter<I>
pub const unsafe fn from_iter_unchecked(iter: I) -> UniqueEntityIter<I> ⓘ
pub const unsafe fn from_iter_unchecked(iter: I) -> UniqueEntityIter<I> ⓘ
Constructs a UniqueEntityIter from an iterator unsafely.
Safety
iter must only yield unique elements.
As in, the resulting iterator must adhere to the safety contract of EntitySetIterator.
pub const unsafe fn from_iter_ref_unchecked(iter: &I) -> &UniqueEntityIter<I> ⓘ
pub const unsafe fn from_iter_ref_unchecked(iter: &I) -> &UniqueEntityIter<I> ⓘ
Constructs a UniqueEntityIter from an iterator unsafely.
Safety
iter must only yield unique elements.
As in, the resulting iterator must adhere to the safety contract of EntitySetIterator.
pub const unsafe fn from_iter_mut_unchecked(
iter: &mut I,
) -> &mut UniqueEntityIter<I> ⓘ
pub const unsafe fn from_iter_mut_unchecked( iter: &mut I, ) -> &mut UniqueEntityIter<I> ⓘ
Constructs a UniqueEntityIter from an iterator unsafely.
Safety
iter must only yield unique elements.
As in, the resulting iterator must adhere to the safety contract of EntitySetIterator.
pub fn into_inner(self) -> I
pub fn into_inner(self) -> I
Returns the inner I.
pub const unsafe fn as_mut_inner(&mut self) -> &mut I
pub const unsafe fn as_mut_inner(&mut self) -> &mut I
Returns a mutable reference to the inner I.
Safety
self must always contain an iterator that yields unique elements,
even while this reference is live.
impl<T, const N: usize> UniqueEntityIter<IntoIter<T, N>>where
T: EntityEquivalent,
impl<T, const N: usize> UniqueEntityIter<IntoIter<T, N>>where
T: EntityEquivalent,
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
Returns an immutable slice of all elements that have not been yielded yet.
Equivalent to array::IntoIter::as_slice.
pub fn as_mut_slice(&mut self) -> &mut UniqueEntityEquivalentSlice<T>
pub fn as_mut_slice(&mut self) -> &mut UniqueEntityEquivalentSlice<T>
Returns a mutable slice of all elements that have not been yielded yet.
Equivalent to array::IntoIter::as_mut_slice.
impl<'a, T> UniqueEntityIter<Iter<'a, T>>where
T: EntityEquivalent,
impl<'a, T> UniqueEntityIter<Iter<'a, T>>where
T: EntityEquivalent,
pub fn as_slice(&self) -> &'a UniqueEntityEquivalentSlice<T>
pub fn as_slice(&self) -> &'a UniqueEntityEquivalentSlice<T>
Views the underlying data as a subslice of the original data.
Equivalent to slice::Iter::as_slice.
impl<'a, T> UniqueEntityIter<IterMut<'a, T>>where
T: EntityEquivalent,
impl<'a, T> UniqueEntityIter<IterMut<'a, T>>where
T: EntityEquivalent,
pub fn into_slice(self) -> &'a mut UniqueEntityEquivalentSlice<T>
pub fn into_slice(self) -> &'a mut UniqueEntityEquivalentSlice<T>
Views the underlying data as a mutable subslice of the original data.
Equivalent to slice::IterMut::into_slice.
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
Views the underlying data as a subslice of the original data.
Equivalent to slice::IterMut::as_slice.
impl<T> UniqueEntityIter<IntoIter<T>>where
T: EntityEquivalent,
impl<T> UniqueEntityIter<IntoIter<T>>where
T: EntityEquivalent,
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
Returns the remaining items of this iterator as a slice.
Equivalent to vec::IntoIter::as_slice.
pub fn as_mut_slice(&mut self) -> &mut UniqueEntityEquivalentSlice<T>
pub fn as_mut_slice(&mut self) -> &mut UniqueEntityEquivalentSlice<T>
Returns the remaining items of this iterator as a mutable slice.
Equivalent to vec::IntoIter::as_mut_slice.
impl<'a, T> UniqueEntityIter<Drain<'a, T>>where
T: EntityEquivalent,
impl<'a, T> UniqueEntityIter<Drain<'a, T>>where
T: EntityEquivalent,
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
pub fn as_slice(&self) -> &UniqueEntityEquivalentSlice<T>
Returns the remaining items of this iterator as a slice.
Equivalent to vec::Drain::as_slice.