Struct EntityClonerBuilder
pub struct EntityClonerBuilder<'w, Filter> { /* private fields */ }Expand description
A builder for configuring EntityCloner. See EntityCloner for more information.
Implementations
impl<'w, Filter> EntityClonerBuilder<'w, Filter>where
Filter: CloneByFilter,
impl<'w, Filter> EntityClonerBuilder<'w, Filter>where
Filter: CloneByFilter,
pub fn clone_entity(
&mut self,
source: Entity,
target: Entity,
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn clone_entity( &mut self, source: Entity, target: Entity, ) -> &mut EntityClonerBuilder<'w, Filter>
Internally calls EntityCloner::clone_entity on the builder’s World.
pub fn finish(self) -> EntityCloner
pub fn finish(self) -> EntityCloner
Finishes configuring EntityCloner returns it.
pub fn with_default_clone_fn(
&mut self,
clone_fn: fn(&SourceComponent<'_>, &mut ComponentCloneCtx<'_, '_>),
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn with_default_clone_fn( &mut self, clone_fn: fn(&SourceComponent<'_>, &mut ComponentCloneCtx<'_, '_>), ) -> &mut EntityClonerBuilder<'w, Filter>
Sets the default clone function to use.
Will be overridden if EntityClonerBuilder::move_components is enabled.
pub fn move_components(
&mut self,
enable: bool,
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn move_components( &mut self, enable: bool, ) -> &mut EntityClonerBuilder<'w, Filter>
Sets whether the cloner should remove any components that were cloned, effectively moving them from the source entity to the target.
This is disabled by default.
The setting only applies to components that are allowed through the filter
at the time EntityClonerBuilder::clone_entity is called.
Enabling this overrides any custom function set with EntityClonerBuilder::with_default_clone_fn.
pub fn override_clone_behavior<T>(
&mut self,
clone_behavior: ComponentCloneBehavior,
) -> &mut EntityClonerBuilder<'w, Filter>where
T: Component,
pub fn override_clone_behavior<T>(
&mut self,
clone_behavior: ComponentCloneBehavior,
) -> &mut EntityClonerBuilder<'w, Filter>where
T: Component,
Overrides the ComponentCloneBehavior for a component in this builder.
This handler will be used to clone the component instead of the global one defined by the EntityCloner.
See Clone Behaviors section of EntityCloner to understand how this affects handler priority.
pub fn override_clone_behavior_with_id(
&mut self,
component_id: ComponentId,
clone_behavior: ComponentCloneBehavior,
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn override_clone_behavior_with_id( &mut self, component_id: ComponentId, clone_behavior: ComponentCloneBehavior, ) -> &mut EntityClonerBuilder<'w, Filter>
Overrides the ComponentCloneBehavior for a component with the given component_id in this builder.
This handler will be used to clone the component instead of the global one defined by the EntityCloner.
See Clone Behaviors section of EntityCloner to understand how this affects handler priority.
pub fn remove_clone_behavior_override<T>(
&mut self,
) -> &mut EntityClonerBuilder<'w, Filter>where
T: Component,
pub fn remove_clone_behavior_override<T>(
&mut self,
) -> &mut EntityClonerBuilder<'w, Filter>where
T: Component,
Removes a previously set override of ComponentCloneBehavior for a component in this builder.
pub fn remove_clone_behavior_override_with_id(
&mut self,
component_id: ComponentId,
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn remove_clone_behavior_override_with_id( &mut self, component_id: ComponentId, ) -> &mut EntityClonerBuilder<'w, Filter>
Removes a previously set override of ComponentCloneBehavior for a given component_id in this builder.
pub fn linked_cloning(
&mut self,
linked_cloning: bool,
) -> &mut EntityClonerBuilder<'w, Filter>
pub fn linked_cloning( &mut self, linked_cloning: bool, ) -> &mut EntityClonerBuilder<'w, Filter>
When true this cloner will be configured to clone entities referenced in cloned components via RelationshipTarget::LINKED_SPAWN.
This will produce “deep” / recursive clones of relationship trees that have “linked spawn”.
impl<'w> EntityClonerBuilder<'w, OptOut>
impl<'w> EntityClonerBuilder<'w, OptOut>
pub fn without_required_by_components(
&mut self,
builder: impl FnOnce(&mut EntityClonerBuilder<'w, OptOut>),
) -> &mut EntityClonerBuilder<'w, OptOut>
pub fn without_required_by_components( &mut self, builder: impl FnOnce(&mut EntityClonerBuilder<'w, OptOut>), ) -> &mut EntityClonerBuilder<'w, OptOut>
By default, any components denied through the filter will automatically deny all of components they are required by too.
This method allows for a scoped mode where any changes to the filter will not involve these requiring components.
If component A is denied in the builder closure here and component B
requires A, then A will be inserted with the value defined in B’s
Component derive.
This assumes A is missing yet at the target entity.
pub fn insert_mode(
&mut self,
insert_mode: InsertMode,
) -> &mut EntityClonerBuilder<'w, OptOut>
pub fn insert_mode( &mut self, insert_mode: InsertMode, ) -> &mut EntityClonerBuilder<'w, OptOut>
Sets whether components are always cloned (InsertMode::Replace, the default) or only if it is missing
(InsertMode::Keep) at the target entity.
This makes no difference if the target is spawned by the cloner.
pub fn deny<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptOut>where
T: Bundle,
pub fn deny<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptOut>where
T: Bundle,
Disallows all components of the bundle from being cloned.
If component A is denied here and component B requires A, then A
is denied as well. See Self::without_required_by_components to alter
this behavior.
pub fn deny_by_ids<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptOut>where
M: Marker,
pub fn deny_by_ids<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptOut>where
M: Marker,
Extends the list of components that shouldn’t be cloned.
Supports filtering by TypeId, ComponentId, BundleId, and IntoIterator yielding one of these.
If component A is denied here and component B requires A, then A
is denied as well. See Self::without_required_by_components to alter
this behavior.
impl<'w> EntityClonerBuilder<'w, OptIn>
impl<'w> EntityClonerBuilder<'w, OptIn>
pub fn without_required_components(
&mut self,
builder: impl FnOnce(&mut EntityClonerBuilder<'w, OptIn>),
) -> &mut EntityClonerBuilder<'w, OptIn>
pub fn without_required_components( &mut self, builder: impl FnOnce(&mut EntityClonerBuilder<'w, OptIn>), ) -> &mut EntityClonerBuilder<'w, OptIn>
By default, any components allowed through the filter will automatically allow all of their required components.
This method allows for a scoped mode where any changes to the filter will not involve required components.
If component A is allowed in the builder closure here and requires
component B, then B will be inserted with the value defined in A’s
Component derive.
This assumes B is missing yet at the target entity.
pub fn allow<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptIn>where
T: Bundle,
pub fn allow<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptIn>where
T: Bundle,
Adds all components of the bundle to the list of components to clone.
If component A is allowed here and requires component B, then B
is allowed as well. See Self::without_required_components
to alter this behavior.
pub fn allow_if_new<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptIn>where
T: Bundle,
pub fn allow_if_new<T>(&mut self) -> &mut EntityClonerBuilder<'w, OptIn>where
T: Bundle,
Adds all components of the bundle to the list of components to clone if the target does not contain them.
If component A is allowed here and requires component B, then B
is allowed as well. See Self::without_required_components
to alter this behavior.
pub fn allow_by_ids<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptIn>where
M: Marker,
pub fn allow_by_ids<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptIn>where
M: Marker,
Extends the list of components to clone.
Supports filtering by TypeId, ComponentId, BundleId, and IntoIterator yielding one of these.
If component A is allowed here and requires component B, then B
is allowed as well. See Self::without_required_components
to alter this behavior.
pub fn allow_by_ids_if_new<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptIn>where
M: Marker,
pub fn allow_by_ids_if_new<M>(
&mut self,
ids: impl FilterableIds<M>,
) -> &mut EntityClonerBuilder<'w, OptIn>where
M: Marker,
Extends the list of components to clone if the target does not contain them.
Supports filtering by TypeId, ComponentId, BundleId, and IntoIterator yielding one of these.
If component A is allowed here and requires component B, then B
is allowed as well. See Self::without_required_components
to alter this behavior.
impl<Filter> EntityClonerBuilder<'_, Filter>where
Filter: CloneByFilter,
impl<Filter> EntityClonerBuilder<'_, Filter>where
Filter: CloneByFilter,
pub fn add_observers(
&mut self,
add_observers: bool,
) -> &mut EntityClonerBuilder<'_, Filter>
pub fn add_observers( &mut self, add_observers: bool, ) -> &mut EntityClonerBuilder<'_, Filter>
Sets the option to automatically add cloned entities to the observers targeting source entity.